@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 1.8.3+   2011/11/11
+ * Version: 1.8.3+   2012/05/05
  */
 
 #ifndef _SECURITY_CCSECURITY_INTERNAL_H
@@ -1275,7 +1275,6 @@ struct ccs_reserved {
 /* Structure for policy manager. */
 struct ccs_manager {
 	struct ccs_acl_head head;
-	bool is_domain;  /* True if manager is a domainname. */
 	/* A path to program or a domainname. */
 	const struct ccs_path_info *manager;
 };
@@ -1592,7 +1591,7 @@ extern unsigned int ccs_memory_used[CCS_MAX_MEMORY_STAT];
  * @a: Pointer to "struct ccs_path_info".
  * @b: Pointer to "struct ccs_path_info".
  *
- * Returns true if @a == @b, false otherwise.
+ * Returns true if @a != @b, false otherwise.
  */
 static inline bool ccs_pathcmp(const struct ccs_path_info *a,
 			       const struct ccs_path_info *b)
@@ -1735,6 +1734,12 @@ static inline pid_t ccs_sys_getppid(void)
 	rcu_read_lock();
 #if (defined(RHEL_MAJOR) && RHEL_MAJOR == 5) || (defined(AX_MAJOR) && AX_MAJOR == 3)
 	pid = rcu_dereference(current->parent)->tgid;
+#elif defined(CONFIG_UTRACE)
+	/*
+	 * RHEL 5.0 kernel does not have RHEL_MAJOR/RHEL_MINOR defined.
+	 * Assume RHEL 5.0 if CONFIG_UTRACE is defined.
+	 */
+	pid = rcu_dereference(current->parent)->tgid;
 #else
 	pid = rcu_dereference(current->real_parent)->tgid;
 #endif
